# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WordDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'word': 'str',
        'speaker': 'int',
        'score': 'str',
        'begin': 'str',
        'length': 'str',
        'stop_sign': 'str'
    }

    attribute_map = {
        'word': 'word',
        'speaker': 'speaker',
        'score': 'score',
        'begin': 'begin',
        'length': 'length',
        'stop_sign': 'stop_sign'
    }

    def __init__(self, word=None, speaker=None, score=None, begin=None, length=None, stop_sign=None):  # noqa: E501
        """WordDto - a model defined in Swagger"""  # noqa: E501

        self._word = None
        self._speaker = None
        self._score = None
        self._begin = None
        self._length = None
        self._stop_sign = None
        self.discriminator = None

        self.word = word
        if speaker is not None:
            self.speaker = speaker
        self.score = score
        if begin is not None:
            self.begin = begin
        if length is not None:
            self.length = length
        if stop_sign is not None:
            self.stop_sign = stop_sign

    @property
    def word(self):
        """Gets the word of this WordDto.  # noqa: E501

        Recognized word  # noqa: E501

        :return: The word of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._word

    @word.setter
    def word(self, word):
        """Sets the word of this WordDto.

        Recognized word  # noqa: E501

        :param word: The word of this WordDto.  # noqa: E501
        :type: str
        """
        if word is None:
            raise ValueError("Invalid value for `word`, must not be `None`")  # noqa: E501

        self._word = word

    @property
    def speaker(self):
        """Gets the speaker of this WordDto.  # noqa: E501

        Identified speaker id  # noqa: E501

        :return: The speaker of this WordDto.  # noqa: E501
        :rtype: int
        """
        return self._speaker

    @speaker.setter
    def speaker(self, speaker):
        """Sets the speaker of this WordDto.

        Identified speaker id  # noqa: E501

        :param speaker: The speaker of this WordDto.  # noqa: E501
        :type: int
        """

        self._speaker = speaker

    @property
    def score(self):
        """Gets the score of this WordDto.  # noqa: E501

        Recognition confidence (0 - 100.00)  # noqa: E501

        :return: The score of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this WordDto.

        Recognition confidence (0 - 100.00)  # noqa: E501

        :param score: The score of this WordDto.  # noqa: E501
        :type: str
        """
        if score is None:
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    @property
    def begin(self):
        """Gets the begin of this WordDto.  # noqa: E501

        Time stamp on which this word was found  # noqa: E501

        :return: The begin of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._begin

    @begin.setter
    def begin(self, begin):
        """Sets the begin of this WordDto.

        Time stamp on which this word was found  # noqa: E501

        :param begin: The begin of this WordDto.  # noqa: E501
        :type: str
        """

        self._begin = begin

    @property
    def length(self):
        """Gets the length of this WordDto.  # noqa: E501

        Word duration  # noqa: E501

        :return: The length of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this WordDto.

        Word duration  # noqa: E501

        :param length: The length of this WordDto.  # noqa: E501
        :type: str
        """

        self._length = length

    @property
    def stop_sign(self):
        """Gets the stop_sign of this WordDto.  # noqa: E501

        Word stop sign  # noqa: E501

        :return: The stop_sign of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._stop_sign

    @stop_sign.setter
    def stop_sign(self, stop_sign):
        """Sets the stop_sign of this WordDto.

        Word stop sign  # noqa: E501

        :param stop_sign: The stop_sign of this WordDto.  # noqa: E501
        :type: str
        """
        self._stop_sign = stop_sign

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WordDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
