from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from speechpro.cloud.speech.recognition.rest.cloud_client.api.packages_api import PackagesApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api.recognize_api import RecognizeApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api.session_api import SessionApi
