# coding: utf-8

# flake8: noqa
"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from speechpro.cloud.speech.recognition.rest.cloud_client.models.asr_advanced_result_dto import ASRAdvancedResultDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.asr_result_dto import ASRResultDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.advanced_recognition_request_dto import AdvancedRecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.audio_file_dto import AudioFileDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.message_dto import MessageDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.package_dto import PackageDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.recognition_request_dto import RecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.sessionless_recognition_request_dto import SessionlessRecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.start_session_request import StartSessionRequest
from speechpro.cloud.speech.recognition.rest.cloud_client.models.status_dto import StatusDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.stream_request_dto import StreamRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.stream_response_dto import StreamResponseDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.word_dto import WordDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.auth_response_dto import AuthResponseDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.auth_status_dto import AuthStatusDto
