# coding: utf-8

# flake8: noqa

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from speechpro.cloud.speech.common.rest.cloud_client.api.session_api import SessionApi

# import ApiClient
from speechpro.cloud.speech.common.rest.cloud_client.cloud_api_client import CloudApiClient
from speechpro.cloud.speech.common.rest.cloud_client.configuration import Configuration
# import models into sdk package
from speechpro.cloud.speech.common.rest.cloud_client.models.auth_response_dto import AuthResponseDto
from speechpro.cloud.speech.common.rest.cloud_client.models.auth_request_dto import AuthRequestDto