# coding: utf-8

# flake8: noqa

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from speechpro.cloud.speech.synthesis.rest.cloud_client.api.synthesize_api import Synthesize
from speechpro.cloud.speech.synthesis.rest.cloud_client.api.session_api import SessionApi

# import ApiClient
from speechpro.cloud.speech.synthesis.rest.cloud_client.cloud_api_client import CloudApiClient
from speechpro.cloud.speech.synthesis.rest.cloud_client.configuration import Configuration
# import models into sdk package
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.close_transaction_response import CloseTransactionResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.credentials import Credentials
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.exception_model import ExceptionModel
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_language import SynthesizeLanguage
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_request import SynthesizeRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_response import SynthesizeResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_sessionless_request import SynthesizeSessionlessRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_text import SynthesizeText
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_voice_type import SynthesizeVoiceType
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_server_configuration_response import WebSocketServerConfigurationResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_synthesize_request import WebSocketSynthesizeRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_text_param import WebSocketTextParam
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.auth_response_dto import AuthResponseDto